@@ -11,8 +11,8 @@ function(input.text,markup.type="plain") {
   if(markup.type == "xml" || markup.type == "xml.drama" 
                           || markup.type == "xml.notitles") {
     # getting rid of the TEI header (if it exists)
-    if(length(grep("</teiheader>",input.text)) > 0) {
-      input.text = input.text[-c(1:(grep("</teiheader>",input.text)))]
+    if(length(grep("</tei[Hh]eader>", input.text)) > 0) {
+      input.text = input.text[-c(1:(grep("</tei[Hh]eader>",input.text)))]
       }
     # the whole text into one (very) long line
     preprocessed.text = paste(input.text, collapse=" ")
