@@ -140,12 +140,10 @@ z.scores.of.all.samples = variables$z.scores.of.all.samples
   .Tcl("font create myDefaultFont -family tahoma -size 8")
   .Tcl("option add *font myDefaultFont")  
   
-    cancel_pause <- FALSE
     tt <- tktoplevel()
     tktitle(tt) <- "Stylometry with R: enter analysis parameters"
     
     push_OK <- function(){
-        cancel_pause <<- TRUE
         tkdestroy(tt)
         }
   
@@ -761,59 +759,56 @@ z.scores.of.all.samples = variables$z.scores.of.all.samples
   # tkgrid(button_1,columnspan="10")
   tkgrid(tklabel(tt,text="    ")) # blank line (i.e., bottom margin)
   
+  # wait until we have input
+  tkwait.window(tt)
   
-  ##########
+  variables$analyzed.features = as.character(tclvalue(analyzed.features))
+  variables$ngram.size = as.numeric(tclvalue(ngram.size))
+  variables$preserve.case = as.logical(as.numeric(tclvalue(preserve.case)))
+  variables$corpus.format = as.character(tclvalue(corpus.format))
+  variables$mfw.min = as.numeric(tclvalue(mfw.min))
+  variables$mfw.max = as.numeric(tclvalue(mfw.max))
+  variables$mfw.incr = as.numeric(tclvalue(mfw.incr))
+  variables$start.at = as.numeric(tclvalue(start.at))
+  variables$culling.min = as.numeric(tclvalue(culling.min))
+  variables$culling.max = as.numeric(tclvalue(culling.max))
+  variables$culling.incr = as.numeric(tclvalue(culling.incr))
+  variables$use.existing.freq.tables = as.logical(as.numeric(tclvalue(use.existing.freq.tables)))
+  variables$use.existing.wordlist = as.logical(as.numeric(tclvalue(use.existing.wordlist)))
+  variables$interactive.files = as.logical(as.numeric(tclvalue(interactive.files)))
+  variables$use.custom.list.of.files = as.logical(as.numeric(tclvalue(use.custom.list.of.files)))
+  variables$analysis.type = as.character(tclvalue(analysis.type))
+  variables$delete.pronouns = as.logical(as.numeric(tclvalue(delete.pronouns)))
+  variables$display.on.screen = as.logical(as.numeric(tclvalue(display.on.screen)))
+  variables$write.pdf.file = as.logical(as.numeric(tclvalue(write.pdf.file)))
+  variables$write.jpg.file = as.logical(as.numeric(tclvalue(write.jpg.file)))
+  variables$write.svg.file = as.logical(as.numeric(tclvalue(write.svg.file)))
+  variables$write.png.file = as.logical(as.numeric(tclvalue(write.png.file)))
+  variables$dump.samples = as.logical(as.numeric(tclvalue(dump.samples)))
+  variables$colors.on.graphs = as.character(tclvalue(colors.on.graphs))
+  variables$pca.visual.flavour = as.character(tclvalue(pca.visual.flavour))
+  variables$titles.on.graphs = as.logical(as.numeric(tclvalue(titles.on.graphs)))
+  variables$dendrogram.layout.horizontal = as.logical(as.numeric(tclvalue(dendrogram.layout.horizontal)))
+  variables$save.distance.tables = as.logical(as.numeric(tclvalue(save.distance.tables)))
+  variables$save.analyzed.features = as.logical(as.numeric(tclvalue(save.analyzed.features)))
+  variables$save.analyzed.freqs = as.logical(as.numeric(tclvalue(save.analyzed.freqs)))
+  variables$sampling = as.character(tclvalue(sampling))
+  variables$sample.size = as.numeric(tclvalue(sample.size))
+  variables$length.of.random.sample = as.numeric(tclvalue(length.of.random.sample))
+  variables$mfw.list.cutoff = as.numeric(tclvalue(mfw.list.cutoff))
+  variables$distance.measure = as.character(tclvalue(distance.measure))
+  variables$corpus.lang = as.character(tclvalue(corpus.lang))
+  variables$consensus.strength = as.numeric(tclvalue(consensus.strength))
+  variables$plot.options.reset = as.logical(as.numeric(tclvalue(plot.options.reset)))
+  variables$plot.custom.height = as.numeric(tclvalue(plot.custom.height))
+  variables$plot.custom.width = as.numeric(tclvalue(plot.custom.width))
+  variables$plot.font.size = as.numeric(tclvalue(plot.font.size))
+  variables$plot.line.thickness = as.numeric(tclvalue(plot.line.thickness))
+  variables$text.id.on.graphs = as.character(tclvalue(text.id.on.graphs))
+  variables$add.to.margins = as.numeric(tclvalue(add.to.margins))
+  variables$label.offset = as.numeric(tclvalue(label.offset))
   
-  repeat{
-    if(cancel_pause){
-      variables$analyzed.features = as.character(tclvalue(analyzed.features))
-      variables$ngram.size = as.numeric(tclvalue(ngram.size))
-      variables$preserve.case = as.logical(as.numeric(tclvalue(preserve.case)))
-      variables$corpus.format = as.character(tclvalue(corpus.format))
-      variables$mfw.min = as.numeric(tclvalue(mfw.min))
-      variables$mfw.max = as.numeric(tclvalue(mfw.max))
-      variables$mfw.incr = as.numeric(tclvalue(mfw.incr))
-      variables$start.at = as.numeric(tclvalue(start.at))
-      variables$culling.min = as.numeric(tclvalue(culling.min))
-      variables$culling.max = as.numeric(tclvalue(culling.max))
-      variables$culling.incr = as.numeric(tclvalue(culling.incr))
-      variables$use.existing.freq.tables = as.logical(as.numeric(tclvalue(use.existing.freq.tables)))
-      variables$use.existing.wordlist = as.logical(as.numeric(tclvalue(use.existing.wordlist)))
-      variables$interactive.files = as.logical(as.numeric(tclvalue(interactive.files)))
-      variables$use.custom.list.of.files = as.logical(as.numeric(tclvalue(use.custom.list.of.files)))
-      variables$analysis.type = as.character(tclvalue(analysis.type))
-      variables$delete.pronouns = as.logical(as.numeric(tclvalue(delete.pronouns)))
-      variables$display.on.screen = as.logical(as.numeric(tclvalue(display.on.screen)))
-      variables$write.pdf.file = as.logical(as.numeric(tclvalue(write.pdf.file)))
-      variables$write.jpg.file = as.logical(as.numeric(tclvalue(write.jpg.file)))
-      variables$write.svg.file = as.logical(as.numeric(tclvalue(write.svg.file)))
-      variables$write.png.file = as.logical(as.numeric(tclvalue(write.png.file)))
-      variables$dump.samples = as.logical(as.numeric(tclvalue(dump.samples)))
-      variables$colors.on.graphs = as.character(tclvalue(colors.on.graphs))
-      variables$pca.visual.flavour = as.character(tclvalue(pca.visual.flavour))
-      variables$titles.on.graphs = as.logical(as.numeric(tclvalue(titles.on.graphs)))
-      variables$dendrogram.layout.horizontal = as.logical(as.numeric(tclvalue(dendrogram.layout.horizontal)))
-      variables$save.distance.tables = as.logical(as.numeric(tclvalue(save.distance.tables)))
-      variables$save.analyzed.features = as.logical(as.numeric(tclvalue(save.analyzed.features)))
-      variables$save.analyzed.freqs = as.logical(as.numeric(tclvalue(save.analyzed.freqs)))
-      variables$sampling = as.character(tclvalue(sampling))
-      variables$sample.size = as.numeric(tclvalue(sample.size))
-      variables$length.of.random.sample = as.numeric(tclvalue(length.of.random.sample))
-      variables$mfw.list.cutoff = as.numeric(tclvalue(mfw.list.cutoff))
-      variables$distance.measure = as.character(tclvalue(distance.measure))
-      variables$corpus.lang = as.character(tclvalue(corpus.lang))
-      variables$consensus.strength = as.numeric(tclvalue(consensus.strength))
-      variables$plot.options.reset = as.logical(as.numeric(tclvalue(plot.options.reset)))
-      variables$plot.custom.height = as.numeric(tclvalue(plot.custom.height))
-      variables$plot.custom.width = as.numeric(tclvalue(plot.custom.width))
-      variables$plot.font.size = as.numeric(tclvalue(plot.font.size))
-      variables$plot.line.thickness = as.numeric(tclvalue(plot.line.thickness))
-      variables$text.id.on.graphs = as.character(tclvalue(text.id.on.graphs))
-      variables$add.to.margins = as.numeric(tclvalue(add.to.margins))
-      variables$label.offset = as.numeric(tclvalue(label.offset))
-      break
-    }
   .Tcl("font delete myDefaultFont")
-  }
-return(variables)
+  
+  return(variables)
 }
